@@ -2,7 +2,7 @@ package Test::SharedFork;
 use strict;
 use warnings;
 use base 'Test::Builder::Module';
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 use Test::Builder 0.32; # 0.32 or later is needed
 use Test::SharedFork::Scalar;
 use Test::SharedFork::Array;
@@ -109,7 +109,7 @@ BEGIN {
     for my $name (qw/ok skip todo_skip current_test/) {
         my $orig = *{"Test::Builder::${name}"}{CODE};
         *{"Test::Builder::${name}"} = sub {
-            local $Test::Builder::Level += 3;
+            local $Test::Builder::Level = $Test::Builder::Level + 3;
             my $lock = $STORE->get_lock(); # RAII
             $orig->(@_);
         };
